package com.idea.buildManage.excel;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.fastjson.JSONObject;
import com.idea.buildManage.model.MnpBuilding;
import com.idea.buildManage.service.MnpBuildingService;
import com.idea.buildManage.service.ParkFloorDiscService;
import com.idea.buildManage.service.ParkInfoService;
import com.rockstar.frame.service.FrameUserService;
import com.rockstar.system.service.SysDictService;
import com.rockstar.util.StringUtils;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Component
public class MnpBuildingListener extends AnalysisEventListener<MnpBuildingExcel> {

    private List<MnpBuilding> list = new ArrayList<>();

    private List<MnpBuildingExcel> excelList = new ArrayList<>();

    private List<MnpBuildingExcel> badList = new ArrayList<>();

    Integer count;

    private JSONObject jsonObject;

    @Autowired
    private MnpBuildingService buildingService;
    @Autowired
    private ParkFloorDiscService floorDiscService;
    @Autowired
    private ParkInfoService parkInfoService;
    @Autowired
    private SysDictService sysDictService;


    public MnpBuildingListener(JSONObject jsonObject) {
        this.jsonObject = jsonObject;
    }


    @Override
    public void invoke(MnpBuildingExcel mnpBuildingExcel, AnalysisContext analysisContext) {
        excelList.add(mnpBuildingExcel);
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {

        if(CollectionUtils.isNotEmpty(excelList)){
            MnpBuilding data;
            MnpBuildingExcel excel = null;
            Map<String, String> discNameIdMap = floorDiscService.getNameIdMap();
            Map<String, String> parkNameIdMap = parkInfoService.getNameIdMap();
            for(int i = 0; i < excelList.size(); i++){
                try {
                    data = new MnpBuilding();
                    excel = excelList.get(i);
                    if (StringUtils.isEmpty(excel.getGroupName())) {
                        throw new RuntimeException("楼盘/小区名称为空");
                    }
                    data.setGroupName(excel.getGroupName());
                    if (StringUtils.isEmpty(excel.getDiscName())) {
                        throw new RuntimeException("分期名称为空");
                    }
                    data.setDiscName(excel.getDiscName());
                    if (StringUtils.isEmpty(excel.getBuildNum())) {
                        throw new RuntimeException("单元楼栋号为空");
                    }
                    data.setBuildNum(excel.getBuildNum());
                    // 判断小区是否存在
                    if(StringUtils.isEmpty(parkNameIdMap.get(excel.getGroupName()))){
                        throw new RuntimeException("楼盘/小区不存在");
                    }
                    data.setGroupId(parkNameIdMap.get(excel.getGroupName()));
                    // 判断分期是否存在
                    if(StringUtils.isEmpty(discNameIdMap.get(excel.getGroupName()))){
                        throw new RuntimeException("分期不存在");
                    }
                    data.setDiscId(discNameIdMap.get(excel.getGroupName()));
                    // 总面积
                    if (StringUtils.isEmpty(excel.getArea())) {
                        throw new RuntimeException("总面积为空");
                    }
                    // 住宅面积
                    if (StringUtils.isEmpty(excel.getResidentialArea())) {
                        throw new RuntimeException("住宅面积为空");
                    }


                    count = list.size();
                    jsonObject.put("successCount", count);
                    jsonObject.put("errorList", badList);
                    jsonObject.put("errorCount", badList.size());
                    //保存
                    saveData();

                    excelList.clear();
                    list.clear();

                }catch (Exception e){
                    e.printStackTrace();
                    String message = e.getMessage();
                    excel.setReason(message);
                    badList.add(excel);
                }
            }
        }

    }

    private void saveData(){
        if (CollectionUtils.isNotEmpty(list)) {
            buildingService.insertBatch(list);
        }
    }


}
